@@ -68,7 +68,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 28 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:339  */
+#line 28 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:339  */
 
 #include "sql_class.h"
 #include "parse_tree_hints.h"
@@ -77,7 +77,7 @@
 
 #define NEW_PTN new (thd->mem_root)
 
-#line 81 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:339  */
+#line 81 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -97,8 +97,8 @@
 
 /* In a future release of Bison, this section will be replaced
    by #include "sql_hints.yy.h".  */
-#ifndef YY_HINT_PARSER_MNT_WORKSPACE_PERCONA_SERVER_5_7_SOURCE_TARBALLS_ROCKS_NEW_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED
-# define YY_HINT_PARSER_MNT_WORKSPACE_PERCONA_SERVER_5_7_SOURCE_TARBALLS_ROCKS_NEW_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED
+#ifndef YY_HINT_PARSER_MNT_JENKINS_WORKSPACE_PS5_7_AUTOBUILD_RELEASE_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED
+# define YY_HINT_PARSER_MNT_JENKINS_WORKSPACE_PS5_7_AUTOBUILD_RELEASE_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -168,11 +168,11 @@ extern int HINT_PARSER_debug;
 
 int HINT_PARSER_parse (class THD *thd, class Hint_scanner *scanner, class PT_hint_list **ret);
 
-#endif /* !YY_HINT_PARSER_MNT_WORKSPACE_PERCONA_SERVER_5_7_SOURCE_TARBALLS_ROCKS_NEW_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED  */
+#endif /* !YY_HINT_PARSER_MNT_JENKINS_WORKSPACE_PS5_7_AUTOBUILD_RELEASE_TEST_PERCONA_SERVER_SQL_SQL_HINTS_YY_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 176 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:358  */
+#line 176 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1331,44 +1331,44 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 126 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 126 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { *ret= (yyvsp[-1].hint_list); }
-#line 1337 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1337 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 128 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 128 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { *ret= (yyvsp[-2].hint_list); }
-#line 1343 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1343 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 130 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 130 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { *ret= NULL; }
-#line 1349 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1349 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 135 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 135 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_list)= NEW_PTN PT_hint_list(thd->mem_root);
             if ((yyval.hint_list) == NULL || (yyval.hint_list)->push_back((yyvsp[0].hint)))
               YYABORT; // OOM
           }
-#line 1359 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1359 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 141 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 141 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyvsp[-1].hint_list)->push_back((yyvsp[0].hint));
             (yyval.hint_list)= (yyvsp[-1].hint_list);
           }
-#line 1368 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1368 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 158 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 158 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             int error;
             char *end= const_cast<char *>((yyvsp[-1].hint_string).str + (yyvsp[-1].hint_string).length);
@@ -1386,345 +1386,345 @@ yyreduce:
                 YYABORT; // OOM
             }
           }
-#line 1390 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1390 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 179 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 179 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.hint_param_table_list).init(thd->mem_root); }
-#line 1396 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1396 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 185 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 185 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_table_list).init(thd->mem_root);
             if ((yyval.hint_param_table_list).push_back((yyvsp[0].hint_param_table)))
               YYABORT; // OOM
           }
-#line 1406 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1406 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 191 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 191 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             if ((yyvsp[-2].hint_param_table_list).push_back((yyvsp[0].hint_param_table)))
               YYABORT; // OOM
             (yyval.hint_param_table_list)= (yyvsp[-2].hint_param_table_list);
           }
-#line 1416 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1416 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 199 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 199 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.hint_param_table_list).init(thd->mem_root); }
-#line 1422 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1422 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 205 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 205 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_table_list).init(thd->mem_root);
             if ((yyval.hint_param_table_list).push_back((yyvsp[0].hint_param_table)))
               YYABORT; // OOM
           }
-#line 1432 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1432 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 211 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 211 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             if ((yyvsp[-2].hint_param_table_list).push_back((yyvsp[0].hint_param_table)))
               YYABORT; // OOM
             (yyval.hint_param_table_list)= (yyvsp[-2].hint_param_table_list);
           }
-#line 1442 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1442 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 219 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 219 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.hint_param_index_list).init(thd->mem_root); }
-#line 1448 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1448 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 225 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 225 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_index_list).init(thd->mem_root);
             if ((yyval.hint_param_index_list).push_back((yyvsp[0].hint_string)))
               YYABORT; // OOM
           }
-#line 1458 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1458 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 231 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 231 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             if ((yyvsp[-2].hint_param_index_list).push_back((yyvsp[0].hint_string)))
               YYABORT; // OOM
             (yyval.hint_param_index_list)= (yyvsp[-2].hint_param_index_list);
           }
-#line 1468 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1468 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 244 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 244 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_table).table= (yyvsp[0].hint_string);
             (yyval.hint_param_table).opt_query_block= NULL_CSTR;
           }
-#line 1477 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1477 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 252 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 252 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_table).table= (yyvsp[-1].hint_string);
             (yyval.hint_param_table).opt_query_block= (yyvsp[0].hint_string);
           }
-#line 1486 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1486 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 261 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 261 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_param_table).table= (yyvsp[0].hint_string);
             (yyval.hint_param_table).opt_query_block= (yyvsp[-1].hint_string);
           }
-#line 1495 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1495 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 268 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 268 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.hint_string)= NULL_CSTR; }
-#line 1501 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1501 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 274 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 274 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_qb_level_hint((yyvsp[-2].hint_string), TRUE, SEMIJOIN_HINT_ENUM, (yyvsp[-1].ulong_num));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1511 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1511 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 281 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 281 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_qb_level_hint((yyvsp[-2].hint_string), FALSE, SEMIJOIN_HINT_ENUM, (yyvsp[-1].ulong_num));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1521 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1521 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 288 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 288 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_qb_level_hint((yyvsp[-2].hint_string), TRUE, SUBQUERY_HINT_ENUM, (yyvsp[-1].ulong_num));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1531 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1531 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 296 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 296 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= 0; }
-#line 1537 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1537 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 298 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 298 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.ulong_num)= (yyvsp[0].ulong_num);
           }
-#line 1545 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1545 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 302 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 302 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.ulong_num)= (yyvsp[-2].ulong_num) | (yyvsp[0].ulong_num);
           }
-#line 1553 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1553 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 308 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 308 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= OPTIMIZER_SWITCH_FIRSTMATCH; }
-#line 1559 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1559 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 309 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 309 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= OPTIMIZER_SWITCH_LOOSE_SCAN; }
-#line 1565 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1565 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 310 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 310 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= OPTIMIZER_SWITCH_MATERIALIZATION; }
-#line 1571 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1571 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 311 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 311 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= OPTIMIZER_SWITCH_DUPSWEEDOUT; }
-#line 1577 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1577 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 315 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 315 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)=
                                    Item_exists_subselect::EXEC_MATERIALIZATION; }
-#line 1584 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1584 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 317 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 317 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     { (yyval.ulong_num)= Item_exists_subselect::EXEC_EXISTS; }
-#line 1590 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1590 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 323 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 323 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_table_level_hint(NULL_CSTR, (yyvsp[-1].hint_param_table_list), TRUE, (yyvsp[-3].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1600 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1600 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 330 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 330 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_table_level_hint((yyvsp[-2].hint_string), (yyvsp[-1].hint_param_table_list), TRUE, (yyvsp[-4].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1610 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1610 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 336 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 336 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_table_level_hint(NULL_CSTR, (yyvsp[-1].hint_param_table_list), FALSE, (yyvsp[-3].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1620 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1620 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 343 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 343 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_table_level_hint((yyvsp[-2].hint_string), (yyvsp[-1].hint_param_table_list), FALSE, (yyvsp[-4].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1630 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1630 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 353 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 353 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_key_level_hint((yyvsp[-2].hint_param_table), (yyvsp[-1].hint_param_index_list), TRUE, (yyvsp[-4].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1640 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1640 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 360 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 360 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_key_level_hint((yyvsp[-2].hint_param_table), (yyvsp[-1].hint_param_index_list), FALSE, (yyvsp[-4].hint_type));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1650 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1650 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 369 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 369 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= BKA_HINT_ENUM;
           }
-#line 1658 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1658 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 373 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 373 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= BNL_HINT_ENUM;
           }
-#line 1666 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1666 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 380 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 380 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= BKA_HINT_ENUM;
           }
-#line 1674 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1674 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 384 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 384 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= BNL_HINT_ENUM;
           }
-#line 1682 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1682 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 391 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 391 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= MRR_HINT_ENUM;
           }
-#line 1690 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1690 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 395 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 395 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= NO_RANGE_HINT_ENUM;
           }
-#line 1698 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1698 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 402 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 402 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= ICP_HINT_ENUM;
           }
-#line 1706 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1706 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 406 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 406 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint_type)= MRR_HINT_ENUM;
           }
-#line 1714 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1714 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 413 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
+#line 413 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy" /* yacc.c:1646  */
     {
             (yyval.hint)= NEW_PTN PT_hint_qb_name((yyvsp[-1].hint_string));
             if ((yyval.hint) == NULL)
               YYABORT; // OOM
           }
-#line 1724 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1724 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
     break;
 
 
-#line 1728 "/mnt/workspace/percona-server-5.7-source-tarballs-rocks-new/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
+#line 1728 "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/sql/sql_hints.yy.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
