@@ -1,13 +1,20 @@
-/* Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2007, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
@@ -109,7 +116,7 @@ public:
       first= new_item;
     if (last != NULL)
     {
-      DBUG_ASSERT(last->next == NULL);
+      assert(last->next == NULL);
       last->next= new_item;
     }
     new_item->previous= last;
@@ -145,7 +152,7 @@ public:
 
   bool is_empty()
   {
-    DBUG_ASSERT(((elements > 0) && (first != NULL)) || ((elements == 0) || (first == NULL)));
+    assert(((elements > 0) && (first != NULL)) || ((elements == 0) || (first == NULL)));
     return (elements == 0);
   }
 
@@ -243,7 +250,7 @@ private:
 
 public:
 
-  inline PROFILING * get_profiling() const { return profiling; };
+  PROFILING * get_profiling() const { return profiling; };
 
 };
 
