@@ -1,18 +1,26 @@
-/*  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+   Copyright (c) 2015, 2021, Oracle and/or its affiliates.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; version 2 of the
-    License.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License, version 2.0, for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
 
 #include "srv_session.h"
 #include "my_dbug.h"
@@ -550,7 +558,9 @@ Srv_session::Session_backup_and_attach::~Session_backup_and_attach()
     session->detach();
     backup_thd->store_globals();
 #ifdef HAVE_PSI_THREAD_INTERFACE
-    PSI_THREAD_CALL(set_connection_type)(backup_thd->get_vio_type());
+    enum_vio_type vio_type= backup_thd->get_vio_type();
+    if (vio_type != NO_VIO_TYPE)
+      PSI_THREAD_CALL(set_connection_type)(vio_type);
 #endif /* HAVE_PSI_THREAD_INTERFACE */
   }
   else if (in_close_session)
@@ -714,8 +724,7 @@ static void set_psi(THD *thd)
 
 
 /**
-  Initializes physical thread to use with session service. The used
-  PSI key is key_thread_daemon_plugin
+  Initializes physical thread to use with session service.
 
   @param plugin Pointer to the plugin structure, passed to the plugin over
                 the plugin init function.
@@ -735,14 +744,6 @@ bool Srv_session::init_thread(const void *plugin)
     return true;
   }
 
-#ifdef HAVE_PSI_THREAD_INTERFACE
-  PSI_thread *psi= PSI_THREAD_CALL
-         (new_thread)(key_thread_daemon_plugin,
-                      NULL /*identity */,
-                      0 /* thread_id*/);
-  PSI_THREAD_CALL(set_thread)(psi);
-#endif
-
   server_session_threads.add(my_thread_self(), plugin);
 
   return false;
@@ -810,10 +811,7 @@ void Srv_session::deinit_thread()
 
   my_set_thread_local(THR_srv_session_thread, NULL);
 
-  DBUG_ASSERT(my_get_thread_local(THR_stack_start_address));
-#ifdef HAVE_PSI_THREAD_INTERFACE
-  PSI_THREAD_CALL(delete_current_thread)();
-#endif
+  assert(my_get_thread_local(THR_stack_start_address));
   my_set_thread_local(THR_stack_start_address, NULL);
   my_thread_end();
 }
@@ -947,7 +945,7 @@ bool Srv_session::open()
   DBUG_ENTER("Srv_session::open");
 
   DBUG_PRINT("info",("Session=%p  THD=%p  DA=%p", this, &thd, &da));
-  DBUG_ASSERT(state == SRV_SESSION_CREATED || state == SRV_SESSION_CLOSED);
+  assert(state == SRV_SESSION_CREATED || state == SRV_SESSION_CLOSED);
 
   thd.set_protocol(&protocol_error);
   thd.push_diagnostics_area(&da);
@@ -1118,7 +1116,7 @@ bool Srv_session::detach()
   DBUG_PRINT("info",("Session=%p THD=%p current_thd=%p",
                      this, &thd, current_thd));
 
-  DBUG_ASSERT(&thd == current_thd);
+  assert(&thd == current_thd);
   thd.restore_globals();
 
   set_psi(NULL);
@@ -1156,7 +1154,7 @@ bool Srv_session::close()
   DBUG_PRINT("info",("Session=%p THD=%p current_thd=%p",
                      this, &thd, current_thd));
 
-  DBUG_ASSERT(state < SRV_SESSION_CLOSED);
+  assert(state < SRV_SESSION_CLOSED);
 
   /*
     RAII
@@ -1251,7 +1249,7 @@ int Srv_session::execute_command(enum enum_server_command command,
     DBUG_RETURN(1);
   }
 
-  DBUG_ASSERT(thd.get_protocol() == &protocol_error);
+  assert(thd.get_protocol() == &protocol_error);
 
   // RAII:the destructor restores the state
   Srv_session::Session_backup_and_attach backup(this, false);
@@ -1278,6 +1276,12 @@ int Srv_session::execute_command(enum enum_server_command command,
   if (command != COM_QUERY)
     thd.reset_for_next_command();
 
+  assert(thd.m_statement_psi == NULL);
+  thd.m_statement_psi= MYSQL_START_STATEMENT(&thd.m_statement_state,
+                                             stmt_info_new_packet.m_key,
+                                             thd.db().str,
+                                             thd.db().length,
+                                             thd.charset(), NULL);
   int ret= dispatch_command(&thd, data, command);
 
   thd.set_protocol(&protocol_error);
