@@ -1,13 +1,20 @@
-/* Copyright (c) 2000, 2012, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -22,14 +29,13 @@ int heap_delete(HP_INFO *info, const uchar *record)
   uchar *pos;
   HP_SHARE *share=info->s;
   HP_KEYDEF *keydef, *end, *p_lastinx;
-
   DBUG_ENTER("heap_delete");
   DBUG_PRINT("enter",("info: 0x%lx  record: 0x%lx", (long) info, (long) record));
 
   test_active(info);
 
   if (info->opt_flag & READ_CHECK_USED && hp_rectest(info,record))
-    DBUG_RETURN(my_errno);			/* Record changed */
+    DBUG_RETURN(my_errno());			/* Record changed */
   share->changed=1;
 
   if ( --(share->records) < share->blength >> 1) share->blength>>=1;
@@ -46,7 +52,7 @@ int heap_delete(HP_INFO *info, const uchar *record)
   info->update=HA_STATE_DELETED;
   hp_free_chunks(&share->recordspace, pos);
   info->current_hash_ptr=0;
-#if !defined(DBUG_OFF) && defined(EXTRA_HEAP_DEBUG)
+#if !defined(NDEBUG) && defined(EXTRA_HEAP_DEBUG)
   DBUG_EXECUTE("check_heap",heap_check_heap(info, 0););
 #endif
 
@@ -54,7 +60,7 @@ int heap_delete(HP_INFO *info, const uchar *record)
 err:
   if (++(share->records) == share->blength)
     share->blength+= share->blength;
-  DBUG_RETURN(my_errno);
+  DBUG_RETURN(my_errno());
 }
 
 
@@ -128,7 +134,8 @@ int hp_delete_key(HP_INFO *info, HP_KEYDEF *keyinfo,
     gpos=pos;
     if (!(pos=pos->next_key))
     {
-      DBUG_RETURN(my_errno=HA_ERR_CRASHED);	/* This shouldn't happend */
+      set_my_errno(HA_ERR_CRASHED);
+      DBUG_RETURN(HA_ERR_CRASHED);	/* This shouldn't happend */
     }
   }
 
@@ -148,8 +155,7 @@ int hp_delete_key(HP_INFO *info, HP_KEYDEF *keyinfo,
   else if (pos->next_key)
   {
     empty=pos->next_key;
-    pos->ptr_to_rec=empty->ptr_to_rec;
-    pos->next_key=empty->next_key;
+    *pos= *empty;
   }
   else
     keyinfo->hash_buckets--;
@@ -158,7 +164,7 @@ int hp_delete_key(HP_INFO *info, HP_KEYDEF *keyinfo,
     DBUG_RETURN (0);
 
   /* Move the last key (lastpos) */
-  lastpos_hashnr = hp_rec_hashnr(keyinfo, lastpos->ptr_to_rec);
+  lastpos_hashnr= lastpos->hash;
   /* pos is where lastpos should be */
   pos=hp_find_hash(&keyinfo->block, hp_mask(lastpos_hashnr, share->blength,
 					    share->records));
@@ -167,7 +173,7 @@ int hp_delete_key(HP_INFO *info, HP_KEYDEF *keyinfo,
     empty[0]=lastpos[0];
     DBUG_RETURN(0);
   }
-  pos_hashnr = hp_rec_hashnr(keyinfo, pos->ptr_to_rec);
+  pos_hashnr= pos->hash;
   /* pos3 is where the pos should be */
   pos3= hp_find_hash(&keyinfo->block,
 		     hp_mask(pos_hashnr, share->blength, share->records));
